const express = require('express');
const router = express.Router();
const bcrypt = require('bcrypt');
const db = require('../db');


// หน้าแรก
router.get('/', (req, res) => {
  res.render('index');
});

// หน้า Products - รองรับการค้นหาและ filter ตามหมวดหมู่
router.get('/products', (req, res) => {
  const searchQuery = req.query.q || '';
  const category = req.query.category || '';

  let sql = 'SELECT * FROM products';
  const values = [];

  if (searchQuery) {
    sql += ' WHERE name LIKE ?';
    values.push(`%${searchQuery}%`);
  } else if (category) {
    sql += ' WHERE category_id = ?';
    values.push(category);
  }

  db.query(sql, values, (err, results) => {
    if (err) {
      console.error(err);
      return res.send('เกิดข้อผิดพลาด');
    }

    res.render('products', {
      products: results,
      query: searchQuery,
      category: category
    });
  });
});

// หน้า Cart
router.get('/cart', (req, res) => {
  const cart = req.session.cart || [];
  res.render('cart', { cart });
});

// หน้า Login
router.get('/login', (req, res) => {
  res.render('login');
});

router.get('/register', (req, res) => {
  res.render('register'); // <-- อ้างถึง register.ejs ที่อยู่ใน /views
});

router.post('/login', (req, res) => {
  const { email, password } = req.body;

  const sql = 'SELECT * FROM users WHERE email = ?';
  db.query(sql, [email], async (err, results) => {
    if (err || results.length === 0) {
      return res.send('ไม่พบผู้ใช้งาน');
    }

    const user = results[0];
    const match = await bcrypt.compare(password, user.password);

    if (match) {
      req.session.user = user;
      res.redirect('/products');
    } else {
      res.send('รหัสผ่านไม่ถูกต้อง');
    }
  });
});
function checkAuthenticated(req, res, next) {
  if (req.session.user) {
    return next();
  }
  res.redirect('/login');
}
router.get('/', (req, res) => {
  // ถ้า login แล้ว ให้ redirect ไปหน้า products
  if (req.session.user) {
    return res.redirect('/products');
  }
  res.render('index');
});
router.get('/logout', (req, res) => {
  req.session.destroy(err => {
    if (err) {
      console.error('Logout error:', err);
      return res.redirect('/');
    }
    res.redirect('/');
  });
});

router.post('/register', async (req, res) => {
  const { name, email, password } = req.body;

  try {
    const hashedPassword = await bcrypt.hash(password, 10);
    const sql = 'INSERT INTO users (name, email, password) VALUES (?, ?, ?)';
    db.query(sql, [name, email, hashedPassword], (err, result) => {
      if (err) {
        console.error(err);
        return res.send('เกิดข้อผิดพลาดในการสมัคร');
      }
      res.redirect('/login');
    });
  } catch (error) {
    console.log(error);
    res.send('ระบบขัดข้อง');
  }
});
router.post('/add-to-cart', (req, res) => {
  const { id, name, price, image } = req.body;

  if (!req.session.cart) req.session.cart = [];

  const existing = req.session.cart.find(item => item.id == id);
  if (existing) {
    existing.quantity += 1;
  } else {
    req.session.cart.push({
      id,
      name,
      price: parseFloat(price),
      image,
      quantity: 1
    });
  }

  res.redirect('/cart');
});

// อัปเดตจำนวนสินค้า
router.post('/update-cart', (req, res) => {
  const { ids, quantities } = req.body;

  if (!req.session.cart) return res.redirect('/cart');

  req.session.cart.forEach((item, i) => {
    const index = ids.indexOf(item.id);
    if (index !== -1) {
      item.quantity = parseInt(quantities[index]) || 1;
    }
  });

  res.redirect('/cart');
});

// ลบสินค้า
router.post('/remove-from-cart', express.json(), (req, res) => {
  const { id } = req.body;
  req.session.cart = (req.session.cart || []).filter(item => item.id != id);
  res.status(200).json({ success: true });
});

// ไปหน้าสั่งซื้อ
router.post('/checkout', (req, res) => {
  const cart = req.session.cart || [];

  if (cart.length === 0) return res.redirect('/cart');

  const total = cart.reduce((sum, item) => sum + item.price * item.quantity, 0);
  req.session.cart = []; // ล้างตะกร้า
  res.render('checkout', { cart, total });
});

module.exports = router;
